@@ -10,6 +10,8 @@
 #' @param df_new The new, subsetted data frame.
 #' @param df_origin The original data frame where the subset (\code{df_new}) stems from;
 #'          use \code{NULL}, if value and variable labels from \code{df_new} should be removed.
+#' @inheritParams as_factor
+#'
 #' @return Returns \code{df_new} with either removed value and variable label attributes
 #'           (if \code{df_origin = NULL}) or with copied value and variable label
 #'           attributes (if \code{df_origin} was the original subsetted data frame).
@@ -18,7 +20,6 @@
 #'         from \code{df_new} are removed.
 #'
 #' @examples
-#' library(dplyr)
 #' data(efc)
 #'
 #' # create subset - drops label attributes
@@ -35,14 +36,18 @@
 #'
 #' # create subset - drops label attributes
 #' efc.sub <- subset(efc, subset = e16sex == 1, select = c(4:8))
-#' # create subset with dplyr's select - attributes are preserved
-#' efc.sub2 <- select(efc, c160age, e42dep, neg_c_7, c82cop1, c84cop3)
-#'
-#' # copy labels from those columns that are available
-#' copy_labels(efc.sub, efc.sub2) %>% str()
+#' if (require("dplyr")) {
+#'   # create subset with dplyr's select - attributes are preserved
+#'   efc.sub2 <- select(efc, c160age, e42dep, neg_c_7, c82cop1, c84cop3)
+#'   # copy labels from those columns that are available
+#'   copy_labels(efc.sub, efc.sub2) %>% str()
+#' }
 #'
+#' # copy labels from only some columns
+#' str(copy_labels(efc.sub, efc, e42dep))
+#' str(copy_labels(efc.sub, efc, -e17age))
 #' @export
-copy_labels <- function(df_new, df_origin = NULL) {
+copy_labels <- function(df_new, df_origin = NULL, ...) {
   # check if old df is NULL. if so, we remove all labels
   # from the data frame.
   if (is.null(df_origin)) {
@@ -56,6 +61,9 @@ copy_labels <- function(df_new, df_origin = NULL) {
       # get matching colnames, because we only copy attributes from variables
       # that also exist in the new data frame (of course)
       cn <- intersect(colnames(df_new), colnames(df_origin))
+      dots <- as.character(match.call(expand.dots = FALSE)$`...`)
+      .dat <- .get_dot_data(df_origin, dots)
+      cn <- intersect(cn, names(.dat))
 
       for (i in cn) {
         # copy variable and value labels
